<?php

/**
 * @file
 * The Context reaction plugin to add asset files.
 *
 * Contextually add asset files to any page on your site.
 */

/**
 * Expose themes as context reactions.
 */
class context_image_lazyload extends context_reaction {

  public $search_scope;

  /**
   * Constructor method.
   */
  public function __construct($plugin, $info) {
    parent::__construct($plugin, $info);

    $this->title = t('Image Lazyload');
  }

  /**
   * Editor form.
   */
  public function editor_form($context) {
    $form = $this->options_form($context);
    return $form;
  }

  /**
   * Submit handler for editor form.
   */
  public function editor_form_submit($context, $values) {
    $_SESSION['context_form_element_count'] = '';
    return $values;
  }

  /**
   * Image Lazyoader config form.
   *
   * Form to select images to lazyload.
   */
  public function options_form($context) {

    $values = $this->fetch_from_context($context);
    $default_theme = variable_get('theme_default', NULL);
    $regions = system_region_list($default_theme);

    $form['#tree'] = TRUE;

    $form['#prefix'] = '<div id="lazyload-form-wrapper">';
    $form['#suffix'] = '</div>';

    $form[$type] = array(
      '#markup' => '<h1>Image Lazyload Options</h1>',
    );

    $form['dom_elements'] = array(
      '#type' => 'fieldset',
      '#title' => 'DOM Element Selector',
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    );

    $form['dom_elements']['element_type'] = array(
      '#type' => 'radios',
      '#options' => [1 => 'Full Content Section', 2 => 'Custom Dom Elements'],
      '#title' => t('Select the Dom element for lazy loading'),
      '#default_value' => isset($values['dom_elements']['element_type']) ? $values['dom_elements']['element_type'] : 1,
    );

    $form['dom_elements']['custom_elementset'] = array(
      '#type' => 'fieldset',
      '#title' => t('Custom Dom Elements'),
      '#description' => t('HTML DOM element id to be scanned for images'),
      '#prefix' => '<div id="custom-element-wrapper">',
      '#suffix' => '</div>',
    );
    if (isset($context->reactions['plugins']['lazy_load']['custom_elementset']['element_count'])) {
      $elem_count = $form_state['values']['reactions']['plugins']['lazy_load']['custom_elementset']['element_count'];
    }
    else {
      $elem_count = $values['dom_elements']['custom_elementset']['element_count'];
    }

    $form['dom_elements']['custom_elementset']['element_count'] = array(
      '#type' => 'select',
      '#title' => 'Select count of elements',
      '#prefix' => '<div id="element-count-wrapper">',
      '#suffix' => '</div>',
      '#options' => range(1, 10),
      '#default_value' => $elem_count,
      '#submit' => array('submit_callback'),
      '#ajax' => array(
        'callback' => 'elements_add_more',
        'method' => 'replace',
        'effect' => 'fade',
        'wrapper' => 'custom-element-wrapper',
      ),
    );
    for ($i = 1; $i <= $elem_count + 1; $i++) {
      $form['dom_elements']['custom_elementset']['element_wrapper_' . $i] = array(
        '#type' => 'fieldset',
        '#title' => t('Element') . " $i",
        '#prefix' => '<div id="custom-element-subwrapper">',
        '#suffix' => '</div>',
      );
      $form['dom_elements']['custom_elementset']['element_wrapper_' . $i]['element_id_' . $i] = array(
        '#type' => 'textfield',
        '#title' => 'Dom Element ID',
        '#description' => t('Enter HTML DOM element id to be scanned for images'),
        '#size' => 22,
        '#default_value' => $values['dom_elements']['custom_elementset']['element_wrapper_' . $i]['element_id_' . $i],
      );
      $form['dom_elements']['custom_elementset']['element_wrapper_' . $i]['element_loadtime_' . $i] = array(
        '#type' => 'textfield',
        '#title' => 'Image Load delay Time',
        '#description' => t('Delay Time in sec to load the images'),
        '#size' => 22,
        '#default_value' => $values['dom_elements']['custom_elementset']['element_wrapper_' . $i]['element_loadtime_' . $i],
      );
    }

    return $form;
  }

  /**
   * Filters deselected files from the listing.
   *
   * Reduces unnecessary conflicts when exporting to Features.
   */
  public function options_form_submit($values) {
    foreach (array_keys($values) as $key) {
      $values[$key] = array_filter($values[$key]);
    }
    return $values;
  }

  /**
   * Implementation of the built-in context plugin class execution.
   */
  public function execute() {

    $contexts = context_active_contexts();
    $classes = array();

    foreach ($contexts as $key => $value) {
      if (!empty($value->reactions[$this->plugin])) {
        foreach ($value->reactions[$this->plugin] as $lazyload_settings) {

          if ($lazyload_settings['element_type'] == 1) {
            $_SESSION['context_image_lazyload'] = 'content';
          }
          else {
            $_SESSION['context_image_lazyload'] = $lazyload_settings['custom_elementset'];
          }

        }
      }
    }
  }

}
